Toast class

Simple toast class

Constructors

Toast()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

bottom → int
final
center → int
final
lengthLong → int
final
lengthShort → int
final
top → int
final

Static Methods

show(String msg, BuildContext context, {int? duration = 1, int? gravity = 0, Color backgroundColor = const Color(0xAA000000), dynamic textStyle = const TextStyle(fontSize: 15, color: Colors.white), double backgroundRadius = 20, bool? rootNavigator, Border? border}) → void